import * as d3 from 'd3';
// and by documentation https://github.com/d3/d3/blob/main/API.md

function renderData(dataElements) {

    let width = 500;
    let height = 500;
    let domain = ["Inclusiveness", "Constructiveness"];

    let scl = [
        "negative",
        "somewhat negative",
        "neutral",
        "somewhat positive",
        "positive"
    ];
    // inclusive, constructive
    let newData = [
        [0, 0, 0, 0, 0],
        [0, 0, 0, 0, 0]
    ];
    // let totalCount = dataElements.length;
    dataElements.forEach(element => {
        if (element.Inclusiveness === "inclusive") {
            let temp = newData[0][4] + 1;
            newData[0][4] = temp;
        } else if (element.Inclusiveness === "somewhat inclusive") {
            let temp = newData[0][3] + 1;
            newData[0][3] = temp;
        } else if (element.Inclusiveness === "neutral") {
            let temp = newData[0][2] + 1;
            newData[0][2] = temp;
        } else if (element.Inclusiveness === "somewhat not inclusive") {
            let temp = newData[0][1] + 1;
            newData[0][1] = temp;
        } else {
            let temp = newData[0][0] + 1;
            newData[0][0] = temp;
        };
        if (element.Constructiveness === "constructive") {
            let temp = newData[1][4] + 1;
            newData[1][4] = temp;
        } else if (element.Constructiveness === "somewhat constructive") {
            let temp = newData[1][3] + 1;
            newData[1][3] = temp;
        } else if (element.Constructiveness === "neutral") {
            let temp = newData[1][2] + 1;
            newData[1][2] = temp;
        } else if (element.Constructiveness === "somewhat not constructive") {
            let temp = newData[1][1] + 1;
            newData[1][1] = temp;
        } else {
            let temp = newData[1][0] + 1;
            newData[1][0] = temp;
        };
    });

    let temp = newData[0][0] * -1;
    newData[0][0] = temp;
    temp = newData[0][1] * -1;
    newData[0][1] = temp;
    temp = newData[1][0] * -1;
    newData[1][0] = temp;
    temp = newData[1][1] * -1;
    newData[1][1] = temp;

    // define min and max for the x axis
    let min;
    let max;
    let min_i = -1 * (newData[0][2] / 2).toFixed(0);
    let min_c = -1 * (newData[1][2] / 2).toFixed(0);
    let max_i = min_i;
    let max_c = min_c;

    for (let i = 0; i < 5; i++) {
        if (newData[0][i] < 0) {
            min_i += newData[0][i];
        } else { max_i += newData[0][i]; };
        if (newData[1][i] < 0) {
            min_c += newData[1][i];
        } else { max_c += newData[1][i]; };
    };

    if (min_i < min_c) {
        min = min_i;
    } else { min = min_c; };

    if (max_i > min_c) {
        max = max_i;
    } else { max = max_c; };

    let data = [];
    let mapData1;
    let mapData2;

    for (let i = 0; i < 5; i++) {
        mapData1 = {};
        mapData2 = {};
        let val = Math.abs(newData[0][i]);
        mapData1["metric"] = domain[0];
        mapData1["value"] = val;
        mapData1["response_name"] = scl[i];
        mapData1["coordStart"] = min_i;
        mapData1["coordEnd"] = min_i + val;
        min_i += val;

        val = Math.abs(newData[1][i]);
        mapData2["metric"] = domain[1];
        mapData2["value"] = val;
        mapData2["response_name"] = scl[i];
        mapData2["coordStart"] = min_c;
        mapData2["coordEnd"] = min_c + val;
        min_c += val;

        data.push(mapData1);
        data.push(mapData2);
    };

    let margin = ({ top: 100, right: 20, bottom: 35, left: 100 });

    // colors for the states
    const color = d3.scaleOrdinal()
        .domain(scl)
        .range(d3.schemePiYG[5]);

    const x = d3.scaleLinear()
        .domain([-100, 300])
        .range([0, 400]);

    // function with g arg assigned to xAxis
    let xAxis = g => g
        .attr("transform", `translate(100,${height-140-margin.top})`)
        .call(d3.axisBottom(x));

    let svg = d3.select("body")
        .append("svg")
        .attr("width", width + margin.left + margin.right)
        .attr("height", height + margin.top + margin.bottom);

    // legend
    let legend = d3.legendColor()
        .scale(color)
        .shape("path", d3.symbol().type(d3.symbolSquare).size(150)())
        .title("Evaluation");

    svg.append("g")
        .attr("class", "legend")
        .attr("transform", `translate(${10}, ${margin.top + 30})`);

    svg.append("g")
        .call(xAxis);

    svg.select(".legend")
        .style("font-size", "12px")
        .call(legend);

    svg.append("g").selectAll("rect")
        .data(data.filter(el => el.metric === "Inclusiveness"))
        .join("rect")
        .attr("fill", color)
        .attr("width", d => { return d.value; })
        .attr("height", "50")
        .attr("x", function(d) { return 200 + d.coordStart; })
        .attr("y", margin.top);

    svg.append("g").selectAll("rect")
        .data(data.filter(el => el.metric === "Constructiveness"))
        .join("rect")
        .attr("fill", color)
        .attr("height", "50")
        .attr("width", d => { return d.value; })
        .attr("x", function(d) { return 200 + d.coordStart; })
        .attr("y", margin.top + 100);

    svg.append("line")
        .style("stroke", "black")
        .attr("x1", margin.left + 100)
        .attr("y1", 85)
        .attr("x2", margin.left + 100)
        .attr("y2", height - 134 - margin.top);

    svg.append("text")
        .attr("fill", "black")
        .attr("x", width / 7)
        .attr("y", "40")
        .style("font-size", "18px")
        .text("Constructiveness and Inclusiveness Evaluation of the PR");

    svg.append("text")
        .attr("fill", "black")
        .attr("x", width / 4.5 + 120)
        .attr("y", "90")
        .style("font-size", "14px")
        .text("Inclusiveness Evaluation");

    svg.append("text")
        .attr("fill", "black")
        .attr("x", width / 4.5 + 120)
        .attr("y", "190")
        .style("font-size", "14px")
        .text("Constructiveness Evaluation");
  
  svg.append("text")
        .attr("fill", "black")
        .attr("x", width / 4.5 + 12)
        .attr("y", "300")
        .style("font-size", "14px")
        .text("Negative, Neutral, Posiitive Evaluations");

}

d3.csv(
    "https://gist.githubusercontent.com/olga-kondr/19118ea60945a0c53d2129035661dd23/raw/3fd6250f786ef325003450c4e56988226f4bdb35/discordjs_comments_evaluation.csv"
).then(data => renderData(data));












/*function renderData(dataElements) {

    let width = 700;
    let height = 400;
    let domain = ["Inclusiveness", "Constructiveness"];

    let scl = [
        "negative",
        "somewhat negative",
        "neutral",
        "somewhat positive",
        "positive"
    ];
    // incl, constr
    let newData = [
        [0, 0, 0, 0, 0],
        [0, 0, 0, 0, 0]
    ];
    
    dataElements.forEach(element => {
        if (element.Inclusiveness === "inclusive") {
            let temp = newData[0][4] + 1;
            newData[0][4] = temp;
        } else if (element.Inclusiveness === "somewhat inclusive") {
            let temp = newData[0][3] + 1;
            newData[0][3] = temp;
        } else if (element.Inclusiveness === "neutral") {
            let temp = newData[0][2] + 1;
            newData[0][2] = temp;
        } else if (element.Inclusiveness === "somewhat not inclusive") {
            let temp = newData[0][1] + 1;
            newData[0][1] = temp;
        } else {
            let temp = newData[0][0] + 1;
            newData[0][0] = temp;
        };
        if (element.Constructiveness === "constructive") {
            let temp = newData[1][4] + 1;
            newData[1][4] = temp;
        } else if (element.Constructiveness === "somewhat constructive") {
            let temp = newData[1][3] + 1;
            newData[1][3] = temp;
        } else if (element.Constructiveness === "neutral") {
            let temp = newData[1][2] + 1;
            newData[1][2] = temp;
        } else if (element.Constructiveness === "somewhat not constructive") {
            let temp = newData[1][1] + 1;
            newData[1][1] = temp;
        } else {
            let temp = newData[1][0] + 1;
            newData[1][0] = temp;
        };
    });

    let temp = newData[0][0] * -1;
    newData[0][0] = temp;
    temp = newData[0][1] * -1;
    newData[0][1] = temp;
    temp = newData[1][0] * -1;
    newData[1][0] = temp;
    temp = newData[1][1] * -1;
    newData[1][1] = temp;

    // define min and max for the x axis
    let min;
    let max;
    let min_i = -1 * (newData[0][2] / 2).toFixed(0);
    let min_c = -1 * (newData[1][2] / 2).toFixed(0);
    let max_i = min_i;
    let max_c = min_c;

    for (let i = 0; i < 5; i++) {
        if (newData[0][i] < 0) {
            min_i += newData[0][i];
        } else { max_i += newData[0][i]; };
        if (newData[1][i] < 0) {
            min_c += newData[1][i];
        } else { max_c += newData[1][i]; };
    };

    if (min_i < min_c) {
        min = min_i;
    } else { min = min_c; };

    if (max_i > min_c) {
        max = max_i;
    } else { max = max_c; };

    // console.log(newData);
    let data = [];
    let mapData1;
    let mapData2;

    for (let i = 0; i < 5; i++) {
        mapData1 = {};
        mapData2 = {};
        mapData1["metric"] = domain[0];
        mapData1["value"] = Math.abs(newData[0][i]);
        mapData1["response_name"] = scl[i];
        mapData1["coord"] = min_i;
        min_i += Math.abs(newData[0][i]);

        mapData2["metric"] = domain[1];
        mapData2["value"] = Math.abs(newData[1][i]);
        mapData2["response_name"] = scl[i];
        mapData2["coord"] = min_c;
        min_c += Math.abs(newData[1][i]);

        data.push(mapData1);
        data.push(mapData2);
    };

    // console.log(data);
    let margin = ({ top: 100, right: 20, bottom: 35, left: 100 });

    // colors for the states
    const color = d3.scaleOrdinal()
        .domain(scl)
        .range(d3.schemePiYG[5]);

    let x = d3.scaleLinear()
        .domain([min, max]).nice()
        .range([margin.left, width - margin.right]);

    let y = d3.scaleBand()
        .domain(domain)
        .range([height - margin.bottom, margin.top])
        .paddingOuter(0.2);

    // function with g arg assigned to xAxis
    let xAxis = g => g
        .attr("transform", `translate(0,${margin.top})`)
        .call(d3.axisTop(x));

    // function with g arg assigned to yAxis
    let yAxis = g => g
        .attr("transform", `translate(${x(0)},0)`)
        .call(d3.axisLeft(y));

    let svg = d3.select("body")
        .append("svg")
        .attr("width", width + margin.left + margin.right)
        .attr("height", height + margin.top + margin.bottom);

    // legend
    let legend = d3.legendColor()
        .scale(color)
        .shape("path", d3.symbol().type(d3.symbolSquare).size(150)())
        .title("Evaluation");

    svg.append("g")
        .attr("class", "legend")
        .attr("transform", `translate(10, ${margin.top + 30})`);

    svg.append("g")
        .call(xAxis);

    svg.append("g")
        .call(yAxis);

    svg.select(".legend")
        .style("font-size", "12px")
        .call(legend);

    svg.append("g").selectAll("rect")
        .data(data.filter(el => el.metric === "Inclusiveness"))
        .join("rect")
        .attr("fill", color)
  // scaling to x axis doesn't work, can't find why
        .attr("width", function(d) { return x(d.value); })
        .attr("height", y.bandwidth() / 2.5)
        .attr("x", function(d) { return x(d.coord); })
        .attr("y", y.bandwidth() / 6 + margin.top);

    svg.append("g").selectAll("rect")
        .data(data.filter(el => el.metric === "Constructiveness"))
        .join("rect")
        .attr("fill", color)
  // scaling to x axis doesn't work, can't find why
        .attr("width", function(d) { return x(d.value); })
        .attr("height", y.bandwidth() / 2.5)
        .attr("x", function(d) { return x(d.coord); })
        .attr("y", y.bandwidth() + margin.top + 15);

    svg.append("text")
        .attr("fill", "black")
        .attr("x", width / 3)
        .attr("y", "30")
        .style("font-size", "18px")
        .text("Constructiveness and Inclusiveness Evaluation");

    svg.append("text")
        .attr("fill", "black")
        .attr("x", width / 4.5 + 100)
        .attr("y", "70")
        .style("font-size", "14px")
        .text("Evaluations");

    svg.append("text")
        .attr("fill", "black")
        .attr("x", -50)
        .attr("y", 200)
        .attr("transform", "translate(30, 300) rotate(270)")
        .style("font-size", "14px")
        .text("Metric");
}

d3.csv(
    "https://gist.githubusercontent.com/olga-kondr/19118ea60945a0c53d2129035661dd23/raw/3fd6250f786ef325003450c4e56988226f4bdb35/discordjs_comments_evaluation.csv"
).then(data => renderData(data)); */